==> certmanager-model-v1alpha3-6.3.0-sources.jar: io/fabric8/certmanager/api/model/acme/v1alpha3/ACMEIssuerDNS01ProviderAcmeDNSFluentImpl.java <==
package io.fabric8.certmanager.api.model.acme.v1alpha3;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import io.fabric8.certmanager.api.model.meta.v1.SecretKeySelector;
import java.lang.Deprecated;
import io.fabric8.certmanager.api.model.meta.v1.SecretKeySelectorFluentImpl;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.Boolean;
import io.fabric8.certmanager.api.model.meta.v1.SecretKeySelectorBuilder;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class ACMEIssuerDNS01ProviderAcmeDNSFluentImpl<A extends ACMEIssuerDNS01ProviderAcmeDNSFluent<A>> extends BaseFluent<A> implements ACMEIssuerDNS01ProviderAcmeDNSFluent<A>{
  public ACMEIssuerDNS01ProviderAcmeDNSFluentImpl() {
  }
  public ACMEIssuerDNS01ProviderAcmeDNSFluentImpl(ACMEIssuerDNS01ProviderAcmeDNS instance) {
    this.withAccountSecretRef(instance.getAccountSecretRef()); 
    this.withHost(instance.getHost()); 
  }
  private SecretKeySelectorBuilder accountSecretRef;
  private String host;
  
  /**
   * This method has been deprecated, please use method buildAccountSecretRef instead.
   * @return The buildable object.
   */
  @Deprecated
  public SecretKeySelector getAccountSecretRef() {
    return this.accountSecretRef!=null ?this.accountSecretRef.build():null;
  }
  public SecretKeySelector buildAccountSecretRef() {
    return this.accountSecretRef!=null ?this.accountSecretRef.build():null;
  }
  public A withAccountSecretRef(SecretKeySelector accountSecretRef) {
    _visitables.get("accountSecretRef").remove(this.accountSecretRef);
    if (accountSecretRef!=null){ this.accountSecretRef= new SecretKeySelectorBuilder(accountSecretRef); _visitables.get("accountSecretRef").add(this.accountSecretRef);} else { this.accountSecretRef = null; _visitables.get("accountSecretRef").remove(this.accountSecretRef); } return (A) this;
  }
  public Boolean hasAccountSecretRef() {
    return this.accountSecretRef != null;
  }
  public A withNewAccountSecretRef(String key,String name) {
    return (A)withAccountSecretRef(new SecretKeySelector(key, name));
  }
  public ACMEIssuerDNS01ProviderAcmeDNSFluent.AccountSecretRefNested<A> withNewAccountSecretRef() {
    return new ACMEIssuerDNS01ProviderAcmeDNSFluentImpl.AccountSecretRefNestedImpl();
  }
  public ACMEIssuerDNS01ProviderAcmeDNSFluent.AccountSecretRefNested<A> withNewAccountSecretRefLike(SecretKeySelector item) {
    return new ACMEIssuerDNS01ProviderAcmeDNSFluentImpl.AccountSecretRefNestedImpl(item);
  }
  public ACMEIssuerDNS01ProviderAcmeDNSFluent.AccountSecretRefNested<A> editAccountSecretRef() {
    return withNewAccountSecretRefLike(getAccountSecretRef());
  }
  public ACMEIssuerDNS01ProviderAcmeDNSFluent.AccountSecretRefNested<A> editOrNewAccountSecretRef() {
    return withNewAccountSecretRefLike(getAccountSecretRef() != null ? getAccountSecretRef(): new SecretKeySelectorBuilder().build());
  }
  public ACMEIssuerDNS01ProviderAcmeDNSFluent.AccountSecretRefNested<A> editOrNewAccountSecretRefLike(SecretKeySelector item) {
    return withNewAccountSecretRefLike(getAccountSecretRef() != null ? getAccountSecretRef(): item);
  }
  public String getHost() {
    return this.host;
  }
  public A withHost(String host) {
    this.host=host; return (A) this;
  }
  public Boolean hasHost() {
    return this.host != null;
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    ACMEIssuerDNS01ProviderAcmeDNSFluentImpl that = (ACMEIssuerDNS01ProviderAcmeDNSFluentImpl) o;
    if (accountSecretRef != null ? !accountSecretRef.equals(that.accountSecretRef) :that.accountSecretRef != null) return false;
    if (host != null ? !host.equals(that.host) :that.host != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(accountSecretRef,  host,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (accountSecretRef != null) { sb.append("accountSecretRef:"); sb.append(accountSecretRef + ","); }
    if (host != null) { sb.append("host:"); sb.append(host); }
    sb.append("}");
    return sb.toString();
  }
  class AccountSecretRefNestedImpl<N> extends SecretKeySelectorFluentImpl<ACMEIssuerDNS01ProviderAcmeDNSFluent.AccountSecretRefNested<N>> implements ACMEIssuerDNS01ProviderAcmeDNSFluent.AccountSecretRefNested<N>,Nested<N>{
    AccountSecretRefNestedImpl(SecretKeySelector item) {
      this.builder = new SecretKeySelectorBuilder(this, item);
    }
    AccountSecretRefNestedImpl() {
      this.builder = new SecretKeySelectorBuilder(this);
    }
    SecretKeySelectorBuilder builder;
    public N and() {
      return (N) ACMEIssuerDNS01ProviderAcmeDNSFluentImpl.this.withAccountSecretRef(builder.build());
    }
    public N endAccountSecretRef() {
      return and();
    }
    
  }
  
}

==> certmanager-model-v1alpha3-6.7.2-sources.jar: io/fabric8/certmanager/api/model/acme/v1alpha3/ACMEIssuerDNS01ProviderAcmeDNSFluentImpl.java <==
package io.fabric8.certmanager.api.model.acme.v1alpha3;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import io.fabric8.certmanager.api.model.meta.v1.SecretKeySelector;
import java.lang.Deprecated;
import io.fabric8.certmanager.api.model.meta.v1.SecretKeySelectorFluentImpl;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.Boolean;
import io.fabric8.certmanager.api.model.meta.v1.SecretKeySelectorBuilder;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class ACMEIssuerDNS01ProviderAcmeDNSFluentImpl<A extends ACMEIssuerDNS01ProviderAcmeDNSFluent<A>> extends BaseFluent<A> implements ACMEIssuerDNS01ProviderAcmeDNSFluent<A>{
  public ACMEIssuerDNS01ProviderAcmeDNSFluentImpl() {
  }
  public ACMEIssuerDNS01ProviderAcmeDNSFluentImpl(ACMEIssuerDNS01ProviderAcmeDNS instance) {
    if (instance != null) {
      this.withAccountSecretRef(instance.getAccountSecretRef());
      this.withHost(instance.getHost());
    }
  }
  private SecretKeySelectorBuilder accountSecretRef;
  private String host;
  
  /**
   * This method has been deprecated, please use method buildAccountSecretRef instead.
   * @return The buildable object.
   */
  @Deprecated
  public SecretKeySelector getAccountSecretRef() {
    return this.accountSecretRef!=null ?this.accountSecretRef.build():null;
  }
  public SecretKeySelector buildAccountSecretRef() {
    return this.accountSecretRef!=null ?this.accountSecretRef.build():null;
  }
  public A withAccountSecretRef(SecretKeySelector accountSecretRef) {
    _visitables.get("accountSecretRef").remove(this.accountSecretRef);
    if (accountSecretRef!=null){ this.accountSecretRef= new SecretKeySelectorBuilder(accountSecretRef); _visitables.get("accountSecretRef").add(this.accountSecretRef);} else { this.accountSecretRef = null; _visitables.get("accountSecretRef").remove(this.accountSecretRef); } return (A) this;
  }
  public Boolean hasAccountSecretRef() {
    return this.accountSecretRef != null;
  }
  public A withNewAccountSecretRef(String key,String name) {
    return (A)withAccountSecretRef(new SecretKeySelector(key, name));
  }
  public ACMEIssuerDNS01ProviderAcmeDNSFluentImpl.AccountSecretRefNested<A> withNewAccountSecretRef() {
    return new ACMEIssuerDNS01ProviderAcmeDNSFluentImpl.AccountSecretRefNestedImpl();
  }
  public ACMEIssuerDNS01ProviderAcmeDNSFluentImpl.AccountSecretRefNested<A> withNewAccountSecretRefLike(SecretKeySelector item) {
    return new ACMEIssuerDNS01ProviderAcmeDNSFluentImpl.AccountSecretRefNestedImpl(item);
  }
  public ACMEIssuerDNS01ProviderAcmeDNSFluentImpl.AccountSecretRefNested<A> editAccountSecretRef() {
    return withNewAccountSecretRefLike(getAccountSecretRef());
  }
  public ACMEIssuerDNS01ProviderAcmeDNSFluentImpl.AccountSecretRefNested<A> editOrNewAccountSecretRef() {
    return withNewAccountSecretRefLike(getAccountSecretRef() != null ? getAccountSecretRef(): new SecretKeySelectorBuilder().build());
  }
  public ACMEIssuerDNS01ProviderAcmeDNSFluentImpl.AccountSecretRefNested<A> editOrNewAccountSecretRefLike(SecretKeySelector item) {
    return withNewAccountSecretRefLike(getAccountSecretRef() != null ? getAccountSecretRef(): item);
  }
  public String getHost() {
    return this.host;
  }
  public A withHost(String host) {
    this.host=host; return (A) this;
  }
  public Boolean hasHost() {
    return this.host != null;
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    ACMEIssuerDNS01ProviderAcmeDNSFluentImpl that = (ACMEIssuerDNS01ProviderAcmeDNSFluentImpl) o;
    if (!java.util.Objects.equals(accountSecretRef, that.accountSecretRef)) return false;

    if (!java.util.Objects.equals(host, that.host)) return false;

    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(accountSecretRef,  host,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (accountSecretRef != null) { sb.append("accountSecretRef:"); sb.append(accountSecretRef + ","); }
    if (host != null) { sb.append("host:"); sb.append(host); }
    sb.append("}");
    return sb.toString();
  }
  class AccountSecretRefNestedImpl<N> extends SecretKeySelectorFluentImpl<ACMEIssuerDNS01ProviderAcmeDNSFluentImpl.AccountSecretRefNested<N>> implements ACMEIssuerDNS01ProviderAcmeDNSFluentImpl.AccountSecretRefNested<N>,Nested<N>{
    AccountSecretRefNestedImpl(SecretKeySelector item) {
      this.builder = new SecretKeySelectorBuilder(this, item);
    }
    AccountSecretRefNestedImpl() {
      this.builder = new SecretKeySelectorBuilder(this);
    }
    SecretKeySelectorBuilder builder;
    public N and() {
      return (N) ACMEIssuerDNS01ProviderAcmeDNSFluentImpl.this.withAccountSecretRef(builder.build());
    }
    public N endAccountSecretRef() {
      return and();
    }
    
  }
  
}
